**Food and Inequality--Jordan 2012

*IOP do file

**Version 8.0
**Caroline Krafft
**Original 10/31/14
**Updated 6/10/15
**STATA


use "FIJO data v1.dta", clear


log using "FIJO log v8.log", replace


*duplicates report caseid midx

sort caseid midx

set seed 2387490


******************************************************************************

*Programs

******************************************************************************

program drop _all

********
*Height
********

use "FIJO data v1.dta", clear


****Program for SES alone

program define ineqoppSESHT, eclass
version 1.0

* run regression of 24 month old girl equivalent height on circumstances
regress ht24mf wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 ///
 month_2-month_23  ///
 if dejure==1 & match==1 & htvalid==1 [pw=hhweight]

* predict regression residual 
predict double  r, resid
*Can't use direct because of months variables

* substitute each C by its mean
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3  ///
   {
sum `x' [aw=hhweight]
gen double `x'm=r(mean) 
ren `x' `x'v
ren `x'm `x'
}

* predict ytilda standardized distribution
predict double ybar  
gen double ytilda=ybar+r


* return all circumstance variables back to their original state
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3  ///
   {
ren `x' `x'm
ren `x'v `x'
}

* calculate inequality indices GE(0) for height and ytilda
ineqdeco ht24mf [aw=hhweight]
 estadd scalar totineq0=$S_i0


 scalar totineq0=$S_i0

ineqdeco ytilda [aw=hhweight]
 estadd scalar ineqwithin0=$S_i0

scalar ineqwithin0=$S_i0


 estadd scalar thetaPr0=1-(ineqwithin0/totineq0)

 scalar thetaPr0=1-(ineqwithin0/totineq0)
display "thetaPr0=" thetaPr0 "   totineq0=" totineq0


**Partial effects

***************************************************************************
*calculate partial contribution to inequality due to parent's education (ME)
* make ME variables equal to their mean
foreach x of varlist faed2-faed6 moed2-moed6 {
rename `x' `x'v
rename `x'm `x'
}

predict double yMEbar
gen double yMEtilda=yMEbar+r

* return ME variables to original state
foreach x of varlist faed2-faed6 moed2-moed6{
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to Wealth & Employment (WQ)
* make WQ equal to their means
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'v
rename `x'm `x'
}

predict double yWQbar 
gen double yWQtilda=yWQbar+r

* return WQ variables to original state
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'm
rename `x'v `x'
}

****************************************************************

* calculate partial inequality shares for each circumstance 


foreach v in ME WQ {

di "inequality measure for `v'"
ineqdeco y`v'tilda [aw=hhweight] 
 estadd scalar partineq`v'0=$S_i0

scalar partineq`v'0=$S_i0

 estadd scalar theta`v'0=1-(partineq`v'0/totineq0)
scalar theta`v'0=1-(partineq`v'0/totineq0)
display "theta`v'0=" theta`v'0


display "***************************************************************"
display "                                                               "
}

drop r wscorem-mtocp3m ybar- yWQtilda
end 


***Loop over years

drop if htvalid!=1


bootstrap s1=totineq0 s2=ineqwithin0 s3=thetaPr0 s4=thetaME0 ///
 s5=thetaWQ0, ///
 reps(500) cluster(v001)   : ineqoppSESHT

esttab using HTBootstrapSpec1.csv, se replace



clear
eststo clear
use "FIJO data v1.dta", clear


********
*Weight
********

****Program for SES alone

program define ineqoppSESWT, eclass
version 1.0

* run regression of 24 month old girl equivalent weight on circumstances
regress wt24mf wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 ///
 month_2-month_23  ///
 if dejure==1 & match==1 & wtvalid==1 [pw=hhweight]

* predict regression residual 
predict double  r, resid
*Can't use direct because of months variables

* substitute each C by its mean
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3  ///
   {
sum `x' [aw=hhweight]
gen double `x'm=r(mean) 
ren `x' `x'v
ren `x'm `x'
}

* predict ytilda standardized distribution
predict double ybar  
gen double ytilda=ybar+r


* return all circumstance variables back to their original state
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3  ///
   {
ren `x' `x'm
ren `x'v `x'
}

* calculate inequality indices GE(0) for weight and ytilda
ineqdeco wt24mf [aw=hhweight]
 estadd scalar totineq0=$S_i0


 scalar totineq0=$S_i0

ineqdeco ytilda [aw=hhweight]
 estadd scalar ineqwithin0=$S_i0

scalar ineqwithin0=$S_i0


 estadd scalar thetaPr0=1-(ineqwithin0/totineq0)

 scalar thetaPr0=1-(ineqwithin0/totineq0)
display "thetaPr0=" thetaPr0 "   totineq0=" totineq0


**Partial effects

***************************************************************************
*calculate partial contribution to inequality due to parent's education (ME)
* make ME variables equal to their mean
foreach x of varlist faed2-faed6 moed2-moed6 {
rename `x' `x'v
rename `x'm `x'
}

predict double yMEbar
gen double yMEtilda=yMEbar+r

* return ME variables to original state
foreach x of varlist faed2-faed6 moed2-moed6{
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to Wealth & Employment (WQ)
* make WQ equal to their means
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'v
rename `x'm `x'
}

predict double yWQbar 
gen double yWQtilda=yWQbar+r

* return WQ variables to original state
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'm
rename `x'v `x'
}

****************************************************************

* calculate partial inequality shares for each circumstance 


foreach v in ME WQ {

di "inequality measure for `v'"
ineqdeco y`v'tilda [aw=hhweight] 
 estadd scalar partineq`v'0=$S_i0

scalar partineq`v'0=$S_i0

 estadd scalar theta`v'0=1-(partineq`v'0/totineq0)
scalar theta`v'0=1-(partineq`v'0/totineq0)
display "theta`v'0=" theta`v'0


display "***************************************************************"
display "                                                               "
}

drop r wscorem-mtocp3m ybar- yWQtilda
end 


***Loop over years

drop if wtvalid!=1


bootstrap s1=totineq0 s2=ineqwithin0 s3=thetaPr0 s4=thetaME0 ///
 s5=thetaWQ0, ///
 reps(500) cluster(v001)   : ineqoppSESWT

esttab using WTBootstrapSpec1.csv, se replace



clear
eststo clear

********
*Weight-for-height
********

use "FIJO data v1.dta", clear


****Program for SES alone

program define ineqoppSESWH, eclass
version 1.0

* run regression of 24 month old girl equivalent weight on circumstances
regress wh24mf wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 ///
 month_2-month_23  ///
 if dejure==1 & match==1 & wtvalid==1 [pw=hhweight]

* predict regression residual 
predict double  r, resid
*Can't use direct because of months variables

* substitute each C by its mean
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3  ///
   {
sum `x' [aw=hhweight]
gen double `x'm=r(mean) 
ren `x' `x'v
ren `x'm `x'
}

* predict ytilda standardized distribution
predict double ybar  
gen double ytilda=ybar+r


* return all circumstance variables back to their original state
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3  ///
   {
ren `x' `x'm
ren `x'v `x'
}

* calculate inequality indices GE(0) for weight and ytilda
ineqdeco wh24mf [aw=hhweight]
 estadd scalar totineq0=$S_i0


 scalar totineq0=$S_i0

ineqdeco ytilda [aw=hhweight]
 estadd scalar ineqwithin0=$S_i0

scalar ineqwithin0=$S_i0


 estadd scalar thetaPr0=1-(ineqwithin0/totineq0)

 scalar thetaPr0=1-(ineqwithin0/totineq0)
display "thetaPr0=" thetaPr0 "   totineq0=" totineq0


**Partial effects

***************************************************************************
*calculate partial contribution to inequality due to parent's education (ME)
* make ME variables equal to their mean
foreach x of varlist faed2-faed6 moed2-moed6 {
rename `x' `x'v
rename `x'm `x'
}

predict double yMEbar
gen double yMEtilda=yMEbar+r

* return ME variables to original state
foreach x of varlist faed2-faed6 moed2-moed6{
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to Wealth & Employment (WQ)
* make WQ equal to their means
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'v
rename `x'm `x'
}

predict double yWQbar 
gen double yWQtilda=yWQbar+r

* return WQ variables to original state
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'm
rename `x'v `x'
}

****************************************************************

* calculate partial inequality shares for each circumstance 


foreach v in ME WQ {

di "inequality measure for `v'"
ineqdeco y`v'tilda [aw=hhweight] 
 estadd scalar partineq`v'0=$S_i0

scalar partineq`v'0=$S_i0

 estadd scalar theta`v'0=1-(partineq`v'0/totineq0)
scalar theta`v'0=1-(partineq`v'0/totineq0)
display "theta`v'0=" theta`v'0


display "***************************************************************"
display "                                                               "
}

drop r wscorem-mtocp3m ybar- yWQtilda
end 


***Loop over years

drop if wtvalid!=1


bootstrap s1=totineq0 s2=ineqwithin0 s3=thetaPr0 s4=thetaME0 ///
 s5=thetaWQ0, ///
 reps(500) cluster(v001)   : ineqoppSESWH

esttab using WHBootstrapSpec1.csv, se replace



clear
eststo clear



********
*Height
********

use "FIJO data v1.dta", clear


****Program for ALL alone

program define ineqoppALLHT, eclass
version 1.0

* run regression of 24 month old girl equivalent height on circumstances
regress ht24mf wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
 month_2-month_23  ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know  dist_prob ///
if dejure==1 & match==1 &htvalid==1  [pw=hhweight]

* predict regression residual 
predict double  r, resid
*Can't use direct because of months variables

* substitute each C by its mean
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know  dist_prob   ///
   {
sum `x' [aw=hhweight]
gen double `x'm=r(mean) 
ren `x' `x'v
ren `x'm `x'
}

* predict ytilda standardized distribution
predict double ybar  
gen double ytilda=ybar+r


* return all circumstance variables back to their original state
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know  dist_prob   ///
   {
ren `x' `x'm
ren `x'v `x'
}

* calculate inequality indices GE(0) for height and ytilda
ineqdeco ht24mf [aw=hhweight]
 estadd scalar totineq0=$S_i0


 scalar totineq0=$S_i0

ineqdeco ytilda [aw=hhweight]
 estadd scalar ineqwithin0=$S_i0

scalar ineqwithin0=$S_i0


 estadd scalar thetaPr0=1-(ineqwithin0/totineq0)

 scalar thetaPr0=1-(ineqwithin0/totineq0)
display "thetaPr0=" thetaPr0 "   totineq0=" totineq0


**Partial effects

***************************************************************************
*calculate partial contribution to inequality due to parent's education (ME)
* make ME variables equal to their mean
foreach x of varlist faed2-faed6 moed2-moed6 {
rename `x' `x'v
rename `x'm `x'
}

predict double yMEbar
gen double yMEtilda=yMEbar+r

* return ME variables to original state
foreach x of varlist faed2-faed6 moed2-moed6{
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to Wealth & Employment (WQ)
* make WQ equal to their means
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'v
rename `x'm `x'
}

predict double yWQbar 
gen double yWQtilda=yWQbar+r

* return WQ variables to original state
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to gender (FE)
* make FE equal to their means
foreach x of varlist ch_female {
rename `x' `x'v
rename `x'm `x'
}

predict double yFEbar 
gen double yFEtilda=yFEbar+r

* return FE variables to original state
foreach x of varlist ch_female  {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to geography (GE)
* make FE equal to their means
foreach x of varlist rural gov_2-gov_12 scamps badia  {
rename `x' `x'v
rename `x'm `x'
}

predict double yGEbar 
gen double yGEtilda=yGEbar+r

* return GE variables to original state
foreach x of varlist rural gov_2-gov_12 scamps badia   {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to food (FO)
* make FO equal to their means
foreach x of varlist chbf_2-chbf_8 other3 exclbf currbf bottle foodfr_2-foodfr_5 liquids grains protein fruitveg {
rename `x' `x'v
rename `x'm `x'
}

predict double yFObar 
gen double yFOtilda=yFObar+r

* return FO variables to original state
foreach x of varlist chbf_2-chbf_8 other3 exclbf currbf bottle foodfr_2-foodfr_5 liquids grains protein fruitveg  {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to health knowledge (HK)
* make HK equal to their means
foreach x of varlist TB_curable know_ORS FP_know  {
rename `x' `x'v
rename `x'm `x'
}

predict double yHKbar 
gen double yHKtilda=yHKbar+r

* return HK variables to original state
foreach x of varlist TB_curable know_ORS FP_know   {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to health conditions (HC)
* make HC equal to their means
foreach x of varlist  diar_2-diar_3 fever_2-fever_3   {
rename `x' `x'v
rename `x'm `x'
}

predict double yHCbar 
gen double yHCtilda=yHCbar+r

* return HC variables to original state
foreach x of varlist  diar_2-diar_3 fever_2-fever_3   {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to health environment (HE)
* make HE equal to their means
foreach x of varlist roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile dist_prob  {
rename `x' `x'v
rename `x'm `x'
}

predict double yHEbar 
gen double yHEtilda=yHEbar+r

* return HE variables to original state
foreach x of varlist roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile dist_prob {
rename `x' `x'm
rename `x'v `x'
}



****************************************************************

* calculate partial inequality shares for each circumstance 


foreach v in ME WQ FE GE FO HK HC HE {

di "inequality measure for `v'"
ineqdeco y`v'tilda [aw=hhweight] 
 estadd scalar partineq`v'0=$S_i0

scalar partineq`v'0=$S_i0

 estadd scalar theta`v'0=1-(partineq`v'0/totineq0)
scalar theta`v'0=1-(partineq`v'0/totineq0)
display "theta`v'0=" theta`v'0


display "***************************************************************"
display "                                                               "
}

drop r wscorem-dist_probm ybar- yHEtilda
end 


***Loop over years

drop if htvalid!=1


bootstrap s1=totineq0 s2=ineqwithin0 s3=thetaPr0 s4=thetaME0 ///
 s5=thetaWQ0  s6=thetaFE0  s7=thetaGE0  s8=thetaFO0 ///
  s9=thetaHK0   s10=thetaHC0  s11=thetaHE0, ///
 reps(500) cluster(v001)   : ineqoppALLHT

esttab using HTBootstrapSpec2.csv, se replace



clear
eststo clear
use "FIJO data v1.dta", clear


********
*Height
********

use "FIJO data v1.dta", clear


****Program for ALL alone

program define ineqoppALLWT, eclass
version 1.0

* run regression of 24 month old girl equivalent weight on circumstances
regress wt24mf wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
 month_2-month_23  ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know  dist_prob ///
if dejure==1 & match==1 &htvalid==1  [pw=hhweight]

* predict regression residual 
predict double  r, resid
*Can't use direct because of months variables

* substitute each C by its mean
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know  dist_prob   ///
   {
sum `x' [aw=hhweight]
gen double `x'm=r(mean) 
ren `x' `x'v
ren `x'm `x'
}

* predict ytilda standardized distribution
predict double ybar  
gen double ytilda=ybar+r


* return all circumstance variables back to their original state
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know  dist_prob   ///
   {
ren `x' `x'm
ren `x'v `x'
}

* calculate inequality indices GE(0) for weight and ytilda
ineqdeco wt24mf [aw=hhweight]
 estadd scalar totineq0=$S_i0


 scalar totineq0=$S_i0

ineqdeco ytilda [aw=hhweight]
 estadd scalar ineqwithin0=$S_i0

scalar ineqwithin0=$S_i0


 estadd scalar thetaPr0=1-(ineqwithin0/totineq0)

 scalar thetaPr0=1-(ineqwithin0/totineq0)
display "thetaPr0=" thetaPr0 "   totineq0=" totineq0


**Partial effects

***************************************************************************
*calculate partial contribution to inequality due to parent's education (ME)
* make ME variables equal to their mean
foreach x of varlist faed2-faed6 moed2-moed6 {
rename `x' `x'v
rename `x'm `x'
}

predict double yMEbar
gen double yMEtilda=yMEbar+r

* return ME variables to original state
foreach x of varlist faed2-faed6 moed2-moed6{
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to Wealth & Employment (WQ)
* make WQ equal to their means
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'v
rename `x'm `x'
}

predict double yWQbar 
gen double yWQtilda=yWQbar+r

* return WQ variables to original state
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to gender (FE)
* make FE equal to their means
foreach x of varlist ch_female {
rename `x' `x'v
rename `x'm `x'
}

predict double yFEbar 
gen double yFEtilda=yFEbar+r

* return FE variables to original state
foreach x of varlist ch_female  {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to geography (GE)
* make FE equal to their means
foreach x of varlist rural gov_2-gov_12 scamps badia  {
rename `x' `x'v
rename `x'm `x'
}

predict double yGEbar 
gen double yGEtilda=yGEbar+r

* return GE variables to original state
foreach x of varlist rural gov_2-gov_12 scamps badia   {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to food (FO)
* make FO equal to their means
foreach x of varlist chbf_2-chbf_8 other3 exclbf currbf bottle foodfr_2-foodfr_5 liquids grains protein fruitveg {
rename `x' `x'v
rename `x'm `x'
}

predict double yFObar 
gen double yFOtilda=yFObar+r

* return FO variables to original state
foreach x of varlist chbf_2-chbf_8 other3 exclbf currbf bottle foodfr_2-foodfr_5 liquids grains protein fruitveg  {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to health knowledge (HK)
* make HK equal to their means
foreach x of varlist TB_curable know_ORS FP_know  {
rename `x' `x'v
rename `x'm `x'
}

predict double yHKbar 
gen double yHKtilda=yHKbar+r

* return HK variables to original state
foreach x of varlist TB_curable know_ORS FP_know   {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to health conditions (HC)
* make HC equal to their means
foreach x of varlist  diar_2-diar_3 fever_2-fever_3   {
rename `x' `x'v
rename `x'm `x'
}

predict double yHCbar 
gen double yHCtilda=yHCbar+r

* return HC variables to original state
foreach x of varlist  diar_2-diar_3 fever_2-fever_3   {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to health environment (HE)
* make HE equal to their means
foreach x of varlist roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile dist_prob  {
rename `x' `x'v
rename `x'm `x'
}

predict double yHEbar 
gen double yHEtilda=yHEbar+r

* return HE variables to original state
foreach x of varlist roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile dist_prob {
rename `x' `x'm
rename `x'v `x'
}



****************************************************************

* calculate partial inequality shares for each circumstance 


foreach v in ME WQ FE GE FO HK HC HE {

di "inequality measure for `v'"
ineqdeco y`v'tilda [aw=hhweight] 
 estadd scalar partineq`v'0=$S_i0

scalar partineq`v'0=$S_i0

 estadd scalar theta`v'0=1-(partineq`v'0/totineq0)
scalar theta`v'0=1-(partineq`v'0/totineq0)
display "theta`v'0=" theta`v'0


display "***************************************************************"
display "                                                               "
}

drop r wscorem-dist_probm ybar- yHEtilda
end 


***Loop over years

drop if htvalid!=1


bootstrap s1=totineq0 s2=ineqwithin0 s3=thetaPr0 s4=thetaME0 ///
 s5=thetaWQ0  s6=thetaFE0  s7=thetaGE0  s8=thetaFO0 ///
  s9=thetaHK0  s10=thetaHC0  s11=thetaHE0, ///
 reps(500) cluster(v001)   : ineqoppALLWT

esttab using WTBootstrapSpec2.csv, se replace



clear
eststo clear
use "FIJO data v1.dta", clear



********
*Weight-for-height
********

use "FIJO data v1.dta", clear


****Program for ALL alone

program define ineqoppALLWH, eclass
version 1.0

* run regression of 24 month old girl equivalent weight on circumstances
regress wh24mf wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
 month_2-month_23  ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know  dist_prob ///
if dejure==1 & match==1 &htvalid==1  [pw=hhweight]

* predict regression residual 
predict double  r, resid
*Can't use direct because of months variables

* substitute each C by its mean
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know  dist_prob   ///
   {
sum `x' [aw=hhweight]
gen double `x'm=r(mean) 
ren `x' `x'v
ren `x'm `x'
}

* predict ytilda standardized distribution
predict double ybar  
gen double ytilda=ybar+r


* return all circumstance variables back to their original state
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know  dist_prob   ///
   {
ren `x' `x'm
ren `x'v `x'
}

* calculate inequality indices GE(0) for weight and ytilda
ineqdeco wh24mf [aw=hhweight]
 estadd scalar totineq0=$S_i0


 scalar totineq0=$S_i0

ineqdeco ytilda [aw=hhweight]
 estadd scalar ineqwithin0=$S_i0

scalar ineqwithin0=$S_i0


 estadd scalar thetaPr0=1-(ineqwithin0/totineq0)

 scalar thetaPr0=1-(ineqwithin0/totineq0)
display "thetaPr0=" thetaPr0 "   totineq0=" totineq0


**Partial effects

***************************************************************************
*calculate partial contribution to inequality due to parent's education (ME)
* make ME variables equal to their mean
foreach x of varlist faed2-faed6 moed2-moed6 {
rename `x' `x'v
rename `x'm `x'
}

predict double yMEbar
gen double yMEtilda=yMEbar+r

* return ME variables to original state
foreach x of varlist faed2-faed6 moed2-moed6{
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to Wealth & Employment (WQ)
* make WQ equal to their means
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'v
rename `x'm `x'
}

predict double yWQbar 
gen double yWQtilda=yWQbar+r

* return WQ variables to original state
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to gender (FE)
* make FE equal to their means
foreach x of varlist ch_female {
rename `x' `x'v
rename `x'm `x'
}

predict double yFEbar 
gen double yFEtilda=yFEbar+r

* return FE variables to original state
foreach x of varlist ch_female  {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to geography (GE)
* make FE equal to their means
foreach x of varlist rural gov_2-gov_12 scamps badia  {
rename `x' `x'v
rename `x'm `x'
}

predict double yGEbar 
gen double yGEtilda=yGEbar+r

* return GE variables to original state
foreach x of varlist rural gov_2-gov_12 scamps badia   {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to food (FO)
* make FO equal to their means
foreach x of varlist chbf_2-chbf_8 other3 exclbf currbf bottle foodfr_2-foodfr_5 liquids grains protein fruitveg {
rename `x' `x'v
rename `x'm `x'
}

predict double yFObar 
gen double yFOtilda=yFObar+r

* return FO variables to original state
foreach x of varlist chbf_2-chbf_8 other3 exclbf currbf bottle foodfr_2-foodfr_5 liquids grains protein fruitveg  {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to health knowledge (HK)
* make HK equal to their means
foreach x of varlist TB_curable know_ORS FP_know  {
rename `x' `x'v
rename `x'm `x'
}

predict double yHKbar 
gen double yHKtilda=yHKbar+r

* return HK variables to original state
foreach x of varlist TB_curable know_ORS FP_know   {
rename `x' `x'm
rename `x'v `x'
}



***************************************************************
*calculate partial contributions to inequality due to health conditions (HC)
* make HC equal to their means
foreach x of varlist  diar_2-diar_3 fever_2-fever_3   {
rename `x' `x'v
rename `x'm `x'
}

predict double yHCbar 
gen double yHCtilda=yHCbar+r

* return HC variables to original state
foreach x of varlist  diar_2-diar_3 fever_2-fever_3   {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to health environment (HE)
* make HE equal to their means
foreach x of varlist roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile dist_prob  {
rename `x' `x'v
rename `x'm `x'
}

predict double yHEbar 
gen double yHEtilda=yHEbar+r

* return HE variables to original state
foreach x of varlist roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile dist_prob {
rename `x' `x'm
rename `x'v `x'
}



****************************************************************

* calculate partial inequality shares for each circumstance 


foreach v in ME WQ FE GE FO HK HC HE {

di "inequality measure for `v'"
ineqdeco y`v'tilda [aw=hhweight] 
 estadd scalar partineq`v'0=$S_i0

scalar partineq`v'0=$S_i0

 estadd scalar theta`v'0=1-(partineq`v'0/totineq0)
scalar theta`v'0=1-(partineq`v'0/totineq0)
display "theta`v'0=" theta`v'0


display "***************************************************************"
display "                                                               "
}

drop r wscorem-dist_probm ybar- yHEtilda
end 


***Loop over years

drop if htvalid!=1


bootstrap s1=totineq0 s2=ineqwithin0 s3=thetaPr0 s4=thetaME0 ///
 s5=thetaWQ0  s6=thetaFE0  s7=thetaGE0  s8=thetaFO0 ///
  s9=thetaHK0  s10=thetaHC0  s11=thetaHE0, ///
 reps(500) cluster(v001)   : ineqoppALLWH

esttab using WHBootstrapSpec2.csv, se replace



clear
eststo clear
use "FIJO data v1.dta", clear




********
*Height
********

use "FIJO data v1.dta", clear


****Program for ALL alone

program define ineqoppEPIHT, eclass
version 1.0

* run regression of 24 month old girl equivalent height on circumstances
regress ht24mf wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
 month_2-month_23  ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know mage_2-mage_7 mtht bspace firstb dist_prob ///
bweight bweightmiss ///
if dejure==1 & match==1 &htvalid==1  [pw=hhweight]

* predict regression residual 
predict double  r, resid
*Can't use direct because of months variables

* substitute each C by its mean
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know mage_2-mage_7 mtht bspace firstb dist_prob   ///
bweight bweightmiss ///
   {
sum `x' [aw=hhweight]
gen double `x'm=r(mean) 
ren `x' `x'v
ren `x'm `x'
}

* predict ytilda standardized distribution
predict double ybar  
gen double ytilda=ybar+r


* return all circumstance variables back to their original state
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know mage_2-mage_7 mtht bspace firstb dist_prob   ///
bweight bweightmiss ///
   {
ren `x' `x'm
ren `x'v `x'
}

* calculate inequality indices GE(0) for height and ytilda
ineqdeco ht24mf [aw=hhweight]
 estadd scalar totineq0=$S_i0


 scalar totineq0=$S_i0

ineqdeco ytilda [aw=hhweight]
 estadd scalar ineqwithin0=$S_i0

scalar ineqwithin0=$S_i0


 estadd scalar thetaPr0=1-(ineqwithin0/totineq0)

 scalar thetaPr0=1-(ineqwithin0/totineq0)
display "thetaPr0=" thetaPr0 "   totineq0=" totineq0


**Partial effects

***************************************************************************
*calculate partial contribution to inequality due to parent's education (ME)
* make ME variables equal to their mean
foreach x of varlist faed2-faed6 moed2-moed6 {
rename `x' `x'v
rename `x'm `x'
}

predict double yMEbar
gen double yMEtilda=yMEbar+r

* return ME variables to original state
foreach x of varlist faed2-faed6 moed2-moed6{
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to Wealth & Employment (WQ)
* make WQ equal to their means
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'v
rename `x'm `x'
}

predict double yWQbar 
gen double yWQtilda=yWQbar+r

* return WQ variables to original state
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to gender (FE)
* make FE equal to their means
foreach x of varlist ch_female {
rename `x' `x'v
rename `x'm `x'
}

predict double yFEbar 
gen double yFEtilda=yFEbar+r

* return FE variables to original state
foreach x of varlist ch_female  {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to geography (GE)
* make FE equal to their means
foreach x of varlist rural gov_2-gov_12 scamps badia  {
rename `x' `x'v
rename `x'm `x'
}

predict double yGEbar 
gen double yGEtilda=yGEbar+r

* return GE variables to original state
foreach x of varlist rural gov_2-gov_12 scamps badia   {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to food (FO)
* make FO equal to their means
foreach x of varlist chbf_2-chbf_8 other3 exclbf currbf bottle foodfr_2-foodfr_5 liquids grains protein fruitveg {
rename `x' `x'v
rename `x'm `x'
}

predict double yFObar 
gen double yFOtilda=yFObar+r

* return FO variables to original state
foreach x of varlist chbf_2-chbf_8 other3 exclbf currbf bottle foodfr_2-foodfr_5 liquids grains protein fruitveg  {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to health knowledge (HK)
* make HK equal to their means
foreach x of varlist TB_curable know_ORS FP_know  {
rename `x' `x'v
rename `x'm `x'
}

predict double yHKbar 
gen double yHKtilda=yHKbar+r

* return HK variables to original state
foreach x of varlist TB_curable know_ORS FP_know   {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to demographics (DM)
* make DM equal to their means
foreach x of varlist mage_2-mage_7 mtht bspace firstb   {
rename `x' `x'v
rename `x'm `x'
}

predict double yDMbar 
gen double yDMtilda=yDMbar+r

* return DM variables to original state
foreach x of varlist mage_2-mage_7 mtht bspace firstb   {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to health conditions (HC)
* make HC equal to their means
foreach x of varlist  diar_2-diar_3 fever_2-fever_3   {
rename `x' `x'v
rename `x'm `x'
}

predict double yHCbar 
gen double yHCtilda=yHCbar+r

* return HC variables to original state
foreach x of varlist  diar_2-diar_3 fever_2-fever_3   {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to health environment (HE)
* make HE equal to their means
foreach x of varlist roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile dist_prob  {
rename `x' `x'v
rename `x'm `x'
}

predict double yHEbar 
gen double yHEtilda=yHEbar+r

* return HE variables to original state
foreach x of varlist roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile dist_prob {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to Epigenetics (HE)
* make HE equal to their means
foreach x of varlist bweight bweightmiss  {
rename `x' `x'v
rename `x'm `x'
}

predict double yEPbar 
gen double yEPtilda=yEPbar+r

* return HE variables to original state
foreach x of varlist bweight bweightmiss {
rename `x' `x'm
rename `x'v `x'
}



****************************************************************

* calculate partial inequality shares for each circumstance 


foreach v in ME WQ FE GE FO HK HC HE DM EP {

di "inequality measure for `v'"
ineqdeco y`v'tilda [aw=hhweight] 
 estadd scalar partineq`v'0=$S_i0

scalar partineq`v'0=$S_i0

 estadd scalar theta`v'0=1-(partineq`v'0/totineq0)
scalar theta`v'0=1-(partineq`v'0/totineq0)
display "theta`v'0=" theta`v'0


display "***************************************************************"
display "                                                               "
}

drop r wscorem-bweightmissm ybar- yEPtilda
end 


***Loop over years

drop if htvalid!=1


bootstrap s1=totineq0 s2=ineqwithin0 s3=thetaPr0 s4=thetaME0 ///
 s5=thetaWQ0  s6=thetaFE0  s7=thetaGE0  s8=thetaFO0 ///
  s9=thetaHK0   s10=thetaHC0  s11=thetaHE0 s12=thetaDM0 s13=thetaEP0, ///
 reps(500) cluster(v001)   : ineqoppEPIHT

esttab using HTBootstrapSpec3.csv, se replace



clear
eststo clear
use "FIJO data v1.dta", clear


********
*Weight-for-Age
********

use "FIJO data v1.dta", clear


****Program for ALL alone

program define ineqoppEPIWT, eclass
version 1.0

* run regression of 24 month old girl equivalent weight on circumstances
regress wt24mf wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
 month_2-month_23  ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know mage_2-mage_7 mtht bspace firstb dist_prob ///
bweight bweightmiss ///
if dejure==1 & match==1 &htvalid==1  [pw=hhweight]

* predict regression residual 
predict double  r, resid
*Can't use direct because of months variables

* substitute each C by its mean
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know mage_2-mage_7 mtht bspace firstb dist_prob   ///
bweight bweightmiss ///
   {
sum `x' [aw=hhweight]
gen double `x'm=r(mean) 
ren `x' `x'v
ren `x'm `x'
}

* predict ytilda standardized distribution
predict double ybar  
gen double ytilda=ybar+r


* return all circumstance variables back to their original state
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know mage_2-mage_7 mtht bspace firstb dist_prob   ///
bweight bweightmiss ///
   {
ren `x' `x'm
ren `x'v `x'
}

* calculate inequality indices GE(0) for weight and ytilda
ineqdeco wt24mf [aw=hhweight]
 estadd scalar totineq0=$S_i0


 scalar totineq0=$S_i0

ineqdeco ytilda [aw=hhweight]
 estadd scalar ineqwithin0=$S_i0

scalar ineqwithin0=$S_i0


 estadd scalar thetaPr0=1-(ineqwithin0/totineq0)

 scalar thetaPr0=1-(ineqwithin0/totineq0)
display "thetaPr0=" thetaPr0 "   totineq0=" totineq0


**Partial effects

***************************************************************************
*calculate partial contribution to inequality due to parent's education (ME)
* make ME variables equal to their mean
foreach x of varlist faed2-faed6 moed2-moed6 {
rename `x' `x'v
rename `x'm `x'
}

predict double yMEbar
gen double yMEtilda=yMEbar+r

* return ME variables to original state
foreach x of varlist faed2-faed6 moed2-moed6{
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to Wealth & Employment (WQ)
* make WQ equal to their means
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'v
rename `x'm `x'
}

predict double yWQbar 
gen double yWQtilda=yWQbar+r

* return WQ variables to original state
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to gender (FE)
* make FE equal to their means
foreach x of varlist ch_female {
rename `x' `x'v
rename `x'm `x'
}

predict double yFEbar 
gen double yFEtilda=yFEbar+r

* return FE variables to original state
foreach x of varlist ch_female  {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to geography (GE)
* make FE equal to their means
foreach x of varlist rural gov_2-gov_12 scamps badia  {
rename `x' `x'v
rename `x'm `x'
}

predict double yGEbar 
gen double yGEtilda=yGEbar+r

* return GE variables to original state
foreach x of varlist rural gov_2-gov_12 scamps badia   {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to food (FO)
* make FO equal to their means
foreach x of varlist chbf_2-chbf_8 other3 exclbf currbf bottle foodfr_2-foodfr_5 liquids grains protein fruitveg {
rename `x' `x'v
rename `x'm `x'
}

predict double yFObar 
gen double yFOtilda=yFObar+r

* return FO variables to original state
foreach x of varlist chbf_2-chbf_8 other3 exclbf currbf bottle foodfr_2-foodfr_5 liquids grains protein fruitveg  {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to health knowledge (HK)
* make HK equal to their means
foreach x of varlist TB_curable know_ORS FP_know  {
rename `x' `x'v
rename `x'm `x'
}

predict double yHKbar 
gen double yHKtilda=yHKbar+r

* return HK variables to original state
foreach x of varlist TB_curable know_ORS FP_know   {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to demographics (DM)
* make DM equal to their means
foreach x of varlist mage_2-mage_7 mtht bspace firstb   {
rename `x' `x'v
rename `x'm `x'
}

predict double yDMbar 
gen double yDMtilda=yDMbar+r

* return DM variables to original state
foreach x of varlist mage_2-mage_7 mtht bspace firstb   {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to health conditions (HC)
* make HC equal to their means
foreach x of varlist  diar_2-diar_3 fever_2-fever_3   {
rename `x' `x'v
rename `x'm `x'
}

predict double yHCbar 
gen double yHCtilda=yHCbar+r

* return HC variables to original state
foreach x of varlist  diar_2-diar_3 fever_2-fever_3   {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to health environment (HE)
* make HE equal to their means
foreach x of varlist roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile dist_prob  {
rename `x' `x'v
rename `x'm `x'
}

predict double yHEbar 
gen double yHEtilda=yHEbar+r

* return HE variables to original state
foreach x of varlist roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile dist_prob {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to epigenetics (EP)
* make HE equal to their means
foreach x of varlist bweight bweightmiss  {
rename `x' `x'v
rename `x'm `x'
}

predict double yEPbar 
gen double yEPtilda=yEPbar+r

* return HE variables to original state
foreach x of varlist bweight bweightmiss {
rename `x' `x'm
rename `x'v `x'
}




****************************************************************

* calculate partial inequality shares for each circumstance 


foreach v in ME WQ FE GE FO HK HC HE DM EP {

di "inequality measure for `v'"
ineqdeco y`v'tilda [aw=hhweight] 
 estadd scalar partineq`v'0=$S_i0

scalar partineq`v'0=$S_i0

 estadd scalar theta`v'0=1-(partineq`v'0/totineq0)
scalar theta`v'0=1-(partineq`v'0/totineq0)
display "theta`v'0=" theta`v'0


display "***************************************************************"
display "                                                               "
}

drop r wscorem-bweightmissm ybar- yEPtilda
end 


***Loop over years

drop if htvalid!=1


bootstrap s1=totineq0 s2=ineqwithin0 s3=thetaPr0 s4=thetaME0 ///
 s5=thetaWQ0  s6=thetaFE0  s7=thetaGE0  s8=thetaFO0 ///
  s9=thetaHK0  s10=thetaHC0  s11=thetaHE0  s12=thetaDM0 s13=thetaEP0, ///
 reps(500) cluster(v001)   : ineqoppEPIWT

esttab using WTBootstrapSpec3.csv, se replace



clear
eststo clear
use "FIJO data v1.dta", clear



********
*Weight-for-height
********

use "FIJO data v1.dta", clear


****Program for ALL alone

program define ineqoppEPIWH, eclass
version 1.0

* run regression of 24 month old girl equivalent weight on circumstances
regress wh24mf wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
 month_2-month_23  ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know mage_2-mage_7 mtht bspace firstb dist_prob ///
bweight bweightmiss ///
if dejure==1 & match==1 &htvalid==1  [pw=hhweight]

* predict regression residual 
predict double  r, resid
*Can't use direct because of months variables

* substitute each C by its mean
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know mage_2-mage_7 mtht bspace firstb dist_prob   ///
bweight bweightmiss ///
   {
sum `x' [aw=hhweight]
gen double `x'm=r(mean) 
ren `x' `x'v
ren `x'm `x'
}

* predict ytilda standardized distribution
predict double ybar  
gen double ytilda=ybar+r


* return all circumstance variables back to their original state
foreach x of varlist wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_5 liquids grains protein fruitveg ///
  diar_2-diar_3 fever_2-fever_3 roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile ///
TB_curable know_ORS FP_know mage_2-mage_7 mtht bspace firstb dist_prob   ///
bweight bweightmiss ///
   {
ren `x' `x'm
ren `x'v `x'
}

* calculate inequality indices GE(0) for weight and ytilda
ineqdeco wh24mf [aw=hhweight]
 estadd scalar totineq0=$S_i0


 scalar totineq0=$S_i0

ineqdeco ytilda [aw=hhweight]
 estadd scalar ineqwithin0=$S_i0

scalar ineqwithin0=$S_i0


 estadd scalar thetaPr0=1-(ineqwithin0/totineq0)

 scalar thetaPr0=1-(ineqwithin0/totineq0)
display "thetaPr0=" thetaPr0 "   totineq0=" totineq0


**Partial effects

***************************************************************************
*calculate partial contribution to inequality due to parent's education (ME)
* make ME variables equal to their mean
foreach x of varlist faed2-faed6 moed2-moed6 {
rename `x' `x'v
rename `x'm `x'
}

predict double yMEbar
gen double yMEtilda=yMEbar+r

* return ME variables to original state
foreach x of varlist faed2-faed6 moed2-moed6{
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to Wealth & Employment (WQ)
* make WQ equal to their means
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'v
rename `x'm `x'
}

predict double yWQbar 
gen double yWQtilda=yWQbar+r

* return WQ variables to original state
foreach x of varlist wscore wscore2  ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3  {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to gender (FE)
* make FE equal to their means
foreach x of varlist ch_female {
rename `x' `x'v
rename `x'm `x'
}

predict double yFEbar 
gen double yFEtilda=yFEbar+r

* return FE variables to original state
foreach x of varlist ch_female  {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to geography (GE)
* make FE equal to their means
foreach x of varlist rural gov_2-gov_12 scamps badia  {
rename `x' `x'v
rename `x'm `x'
}

predict double yGEbar 
gen double yGEtilda=yGEbar+r

* return GE variables to original state
foreach x of varlist rural gov_2-gov_12 scamps badia   {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to food (FO)
* make FO equal to their means
foreach x of varlist chbf_2-chbf_8 other3 exclbf currbf bottle foodfr_2-foodfr_5 liquids grains protein fruitveg {
rename `x' `x'v
rename `x'm `x'
}

predict double yFObar 
gen double yFOtilda=yFObar+r

* return FO variables to original state
foreach x of varlist chbf_2-chbf_8 other3 exclbf currbf bottle foodfr_2-foodfr_5 liquids grains protein fruitveg  {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to health knowledge (HK)
* make HK equal to their means
foreach x of varlist TB_curable know_ORS FP_know  {
rename `x' `x'v
rename `x'm `x'
}

predict double yHKbar 
gen double yHKtilda=yHKbar+r

* return HK variables to original state
foreach x of varlist TB_curable know_ORS FP_know   {
rename `x' `x'm
rename `x'v `x'
}


***************************************************************
*calculate partial contributions to inequality due to demographics (DM)
* make DM equal to their means
foreach x of varlist mage_2-mage_7 mtht bspace firstb   {
rename `x' `x'v
rename `x'm `x'
}

predict double yDMbar 
gen double yDMtilda=yDMbar+r

* return DM variables to original state
foreach x of varlist mage_2-mage_7 mtht bspace firstb   {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to health conditions (HC)
* make HC equal to their means
foreach x of varlist  diar_2-diar_3 fever_2-fever_3   {
rename `x' `x'v
rename `x'm `x'
}

predict double yHCbar 
gen double yHCtilda=yHCbar+r

* return HC variables to original state
foreach x of varlist  diar_2-diar_3 fever_2-fever_3   {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to health environment (HE)
* make HE equal to their means
foreach x of varlist roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile dist_prob  {
rename `x' `x'v
rename `x'm `x'
}

predict double yHEbar 
gen double yHEtilda=yHEbar+r

* return HE variables to original state
foreach x of varlist roomspp c_wealth c_wealth2 c_nosewer c_water_2 c_water_3 c_water_4 water_2 water_3 water_4 toilet_2 hh_smoke cigarettes nargile dist_prob {
rename `x' `x'm
rename `x'v `x'
}

***************************************************************
*calculate partial contributions to inequality due to Epigenetics (EP)
* make HE equal to their means
foreach x of varlist bweight bweightmiss  {
rename `x' `x'v
rename `x'm `x'
}

predict double yEPbar 
gen double yEPtilda=yEPbar+r

* return HE variables to original state
foreach x of varlist bweight bweightmiss {
rename `x' `x'm
rename `x'v `x'
}

****************************************************************

* calculate partial inequality shares for each circumstance 


foreach v in ME WQ FE GE FO HK HC HE DM EP {

di "inequality measure for `v'"
ineqdeco y`v'tilda [aw=hhweight] 
 estadd scalar partineq`v'0=$S_i0

scalar partineq`v'0=$S_i0

 estadd scalar theta`v'0=1-(partineq`v'0/totineq0)
scalar theta`v'0=1-(partineq`v'0/totineq0)
display "theta`v'0=" theta`v'0


display "***************************************************************"
display "                                                               "
}

drop r wscorem-bweightmissm ybar- yEPtilda
end 


***Loop over years

drop if htvalid!=1


bootstrap s1=totineq0 s2=ineqwithin0 s3=thetaPr0 s4=thetaME0 ///
 s5=thetaWQ0  s6=thetaFE0  s7=thetaGE0  s8=thetaFO0 ///
  s9=thetaHK0  s10=thetaHC0  s11=thetaHE0 s12=thetaDM0 s13=thetaEP0, ///
 reps(500) cluster(v001)   : ineqoppEPIWH

esttab using WHBootstrapSpec3.csv, se replace



clear
eststo clear
use "FIJO data v1.dta", clear



log close

