**Food and Inequality--Jordan 2012

*Data prep

**Version 6.0 ALT
**Caroline Krafft
**Original 11/11/14
**Updated 6/10/15
**STATA


*Household data
use "JOHR6ADT/JOHR6AFL.DTA", clear

***Household health conditions

gen sleep_rooms=hv216

gen rooms=sh116a

gen hhsize=hv009

gen roomspp=hhsize/rooms

la var roomspp "Persons per room" 

gen hh_smoke=(hv252!=0)

la var hh_smoke "Household members smoke"

**** Sanitation and water 

egen hhincluster=count(hv001), by(hv001)

*Own water
gen water=.
replace water=2 if hv201==11 & hv237==1
replace water=3 if hv201==11 & hv237==0
replace water=1 if hv201==71
replace water=4 if hv201!=11 & hv201!=71

la def Lwater 1 "Bottled" 2 "Piped to dwelling treated" 3 "Piped to dwelling not treated" 4 "Other" 
la val water Lwater

tabu water, gen(water_)

labnoeq water_?

*Other HHs in cluster water

foreach num of numlist 1/4 {

egen allc_water_`num'=sum(water_`num'), by(hv001)

gen c_water_`num'=(allc_water_`num'-water_`num')/(hhincluster-1)

}

la var c_water_1 "Cluster share of households with bottled water"
la var c_water_2 "Cluster share of households with water piped in and treated"
la var c_water_3 "Cluster share of households with water piped in and not treated"
la var c_water_4 "Cluster share of households with other water source"

*Own toilet
gen toilet=.
replace toilet=1 if hv205==11
replace toilet=2 if hv205!=11 

la def Ltoilet 1 "Flush to sewer" 2 "Not flushing to sewer" 
la val toilet Ltoilet

tabu toilet, gen(toilet_)

*Other households in cluster toilet
egen allc_nosewer=sum(toilet_2), by(hv001)
gen c_nosewer=(allc_nosewer-toilet_2)/(hhincluster-1)

la var c_nosewer "Cluster share of households not flushing to sewer"


******Cluster other household wealth scores

sum hv271 [aw=hv007]

gen wealth=(hv271-r(min))/r(sd)

egen allhhwealth=sum(wealth), by(hv001)

gen othhhwealth=(allhhwealth-wealth)/(hhincluster-1)

sum hv271

gen c_wealth=othhhwealth
gen c_wealth2=c_wealth*c_wealth/100

la var c_wealth "Average cluster wealth factor"

la var c_wealth2 "Average cluster wealth factor sq./100"



keep hv002 hv001 sleep_rooms rooms hhsize roomspp c_nosewer ///
c_water_1 c_water_2 c_water_3 c_water_4 c_wealth c_wealth2 ///
water water_1 water_2 water_3 water_4 hh_smoke sh110*

rename hv001 v001
rename hv002 v002

save "HH Char FIOJ.dta", replace


*Child data
use "JOKR6ADT/JOKR6AFL.DTA", clear


merge m:1 v001 v002 using "HH Char FIOJ.dta"

tabu _merge
drop if _merge==2
drop _merge

*************************
*Indicators--as observed
*************************

****Making hhweight, sample weight divided by a million

gen hhweight=v005/1000000


***Height for age and stunting, 0-5, WHO standards, is available

tabu hw70

gen hta_sd=.
replace hta_sd=hw70/100 if hw70>=-600 & hw70<=600 

tabu hta_sd

sum hta_sd [aw=hhweight]

gen stunt=.
replace stunt=0 if hta_sd!=.
replace stunt=1 if hta_sd<-2

tabu stunt [aw=hhweight]


***Weight for age and underweight, 0-5, WHO standards, is available

tabu hw71

gen wta_sd=.
replace wta_sd=hw71/100 if hw71>=-600 & hw71<=600 

tabu wta_sd

sum wta_sd [aw=hhweight]

gen underw=.
replace underw=0 if wta_sd!=.
replace underw=1 if wta_sd<-2

tabu underw [aw=hhweight]


***Weight for height and wasting, 0-5, WHO standards, is available

tabu hw72

gen wth_sd=.
replace wth_sd=hw72/100 if hw72>=-600 & hw72<=600 

tabu wth_sd

sum wth_sd [aw=hhweight]

gen waste=.
replace waste =0 if wth_sd!=.
replace waste =1 if wth_sd<-2

tabu waste [aw=hhweight]



***Stat sig.?

regress stunt [aw=hhweight], cluster(v001)
test _cons=.023

regress underw [aw=hhweight], cluster(v001)
test _cons=.023

regress waste [aw=hhweight], cluster(v001)
test _cons=.023

regress hta_sd [aw=hhweight], cluster(v001)
test _cons=0

regress wta_sd [aw=hhweight], cluster(v001)
test _cons=0

regress wth_sd [aw=hhweight], cluster(v001)
test _cons=0


****************
*Outcomes
****************


***Creation of height for age from zs if all were 24 month female
*gen y=M(t)*(1+(L(t)*S(t)*Z))^(1/L(t))
gen ht24mf=85.7153*(1+(1*0.03764*hta_sd))^(1/1)


*Weight-based-measures
*Positive
*=(zind-3)*SD23pos+SD3pos
*Negative
*=(zind+3)*SD23neg+SD3neg
*SD3pos=M(t)*[1+L(t)*S(t)*3]^(1/L(t))
*SD3neg=M(t)*[1+L(t)*S(t)*(-3)]^(1/L(t))
*SD23pos=M(t)*[1+L(t)*S(t)*3]^(1/L(t))-M(t)*[1+L(t)*S(t)*2]^(1/L(t))
*SD23neg=M(t)*[1+L(t)*S(t)*(-2)]^(1/L(t))-M(t)*[1+L(t)*S(t)*(-3)]^(1/L(t))

***Creation of weight for age from zs if all were 24 month female
*gen y=M(t)*(1+(L(t)*S(t)*Z))^(1/L(t))
gen wt24mf=11.4775*(1+((-0.2941)*0.12390*wta_sd))^(1/(-0.2941)) if wta_sd>=-3 & wta_sd<=3
replace wt24mf=(wta_sd-3)*(11.4775*(1+((-0.2941)*0.12390*3))^(1/(-0.2941))-11.4775*(1+((-0.2941)*0.12390*2))^(1/(-0.2941)))+11.4775*(1+((-0.2941)*0.12390*3))^(1/(-0.2941)) if wta_sd>3
replace wt24mf=(wta_sd+3)*(11.4775*(1+((-0.2941)*0.12390*(-2)))^(1/(-0.2941))-11.4775*(1+((-0.2941)*0.12390*(-3)))^(1/(-0.2941)))+11.4775*(1+((-0.2941)*0.12390*(-3)))^(1/(-0.2941)) if wta_sd<-3


***Creation of weight for height from zs if all were at median height of 24 month female
*gen y=M(t)*(1+(L(t)*S(t)*Z))^(1/L(t))
gen wh24mf=11.5186*(1+((-0.3833)*0.08895*wth_sd))^(1/(-0.3833)) if wth_sd>=-3 & wth_sd<=3
replace wh24mf=(wth_sd-3)*(11.5186*(1+((-0.3833)*0.08895*3))^(1/(-0.3833))-11.5186*(1+((-0.3833)*0.08895*2))^(1/(-0.3833)))+11.5186*(1+((-0.3833)*0.08895*3))^(1/(-0.3833)) if wth_sd>3
replace wh24mf=(wth_sd+3)*(11.5186*(1+((-0.3833)*0.08895*(-2)))^(1/(-0.3833))-11.5186*(1+((-0.3833)*0.08895*(-3)))^(1/(-0.3833)))+11.5186*(1+((-0.3833)*0.08895*(-3)))^(1/(-0.3833)) if wth_sd<-3



***************************************************
*Indicators--by background characteristics
***************************************************

*Birth spacing

tabu b11 bord, miss

tabu b0 if bord!=1 & b11==., miss
*All first births with missing data

gen bspace=b11

gen firstb=0
replace firstb=1 if b11==.

sum bspace [aw=hhweight]

replace bspace=r(mean) if firstb==1

la var bspace "Birth spacing (months)"

la var firstb "First birth"

*Wealth quintile (population, weighted)

la var v190 "Wealth quintile" 

tabu v190, gen(wiq)

*Wealth score

sum v191

gen wscore=(v191-r(min))/r(sd)

label variable wscore "Wealth Score"

gen wscore2=wscore*wscore/100

label variable wscore2 "Wealth Score Sq./100"

*Region is v024

tabu v024, gen(region)

rename region1 central
rename region2 north
rename region3 south

*sgovern is governorate of residence

tabu sgovern, gen(gov_)

labnoeq gov_?
labnoeq gov_1?

*urban/rural for use with region
gen rural=.
replace rural=0 if v025==1
replace rural=1 if v025==2

label variable rural "Rural"

*Mother's education

gen moed_cat=s105_r
*Separate diplomas from BA+
replace moed_cat=5 if s105_q==7 | s105_q==8

label define Led_cat            0 "No education" ///
           1 Elementary ///
           2 Preparatory ///
           3 Secondary ///
           4 Diploma ///
           5 "University and above" 

label values moed_cat Led_cat
la var moed_cat "Mother's Education" 

tabu moed_cat, gen(moed)

labnoeq moed?

*Father's education

gen faed_cat=s804_r
*Separate diplomas from BA+
replace faed_cat=5 if s804_q==7 | s804_q==8
replace faed_cat=. if faed_cat==8

label values faed_cat Led_cat
label variable faed_cat "Father's Education"

tabu faed_cat, gen(faed)

labnoeq faed?

*Father's occupation
gen ftocp1d=v705
replace ftocp1d=4 if ftocp1d==5
replace ftocp1d=0 if ftocp1d==. 

label copy V705 Lftocp1d

label def Lftocp1d 4 "Agricultural" 10 "Not present/not working", modify

la val ftocp1d Lftocp1d
label variable ftocp1d "Father's Occupation"

tabu ftocp1d, gen(ftocp)

labnoeq ftocp?

*Father's employment status
gen ftempst=s810
replace ftempst=3 if ftempst==4
replace ftempst=0 if ftempst==.

label define Lftempst 0 "Not present/not working" 1 "Wage worker" 2 "Employer" 3 "Self-employed" 
la val ftempst Lftempst
la var ftempst "Father's Employment Status" 


tabu ftempst, gen(ftemp)

labnoeq ftemp?

*Mother's occupation
gen mtocp1d=v717
replace mtocp1d=2 if mtocp1d>=2 & mtocp1d<.

la def Lmtocp1d 0 "Not working " 1 "Professional/technical/managerial" 2 "Other occupations"

la val mtocp1d Lmtocp1d
la var mtocp1d "Mother's Occupation"

tabu mtocp1d, gen(mtocp)

labnoeq mtocp?


*Mother's employment status
gen mtempst=s814
replace mtempst=0 if mtempst==.
replace mtempst=2 if mtempst>1 & mtempst<.

label define Lmtempst 0 "Not working "1 "Wage worker" 2 "Other work"
la val mtempst Lmtempst
la var mtempst "Mother's Employment Status" 

tabu mtempst, gen(mtemp)

labnoeq mtemp?


*Mother's age

tabu v013, gen(mage_)

labnoeq mage_?


*Mother's height

gen mtht=.
replace mtht=v438/10 if v438<1983

label variable mtht "Mother's height (in cm.)"


*m19 is child's weight at birth

gen bweight=m19/1000 if m19!=9996 & m19!=9998

gen bweightmiss=(m19==9996 | m19==9998) 

sum bweight [aw=hhweight]
replace bweight=r(mean) if bweight==. 

la var bweight "Birth weight in kg"
la var bweightmiss "Birth weight in kg missing"

*b4 is child sex

gen ch_female=0 if b4==1
replace ch_female=1 if b4==2

label variable ch_female "Female"

*b8 is child age (years)
*hw1 is child age (months) 

tabu hw1, gen(month_)

labnoeq month_?


*b1 is month of birth
tabu b1, gen(mob)

labnoeq mob?


*v218 is # living children
*v201 is # children ever born

*v467d is whether getting medical care for self, distance is a problem

tabu v467d

gen dist_prob=.
replace dist_prob=0 if v467d==2
replace dist_prob=1 if v467d==1

label variable dist_prob "Distance to health care problematic"

gen badia=sbadia
replace badia=1 if badia==2

label variable badia "Badia" 

****Sanitation and water

gen toilet=.
replace toilet=1 if v116==11
replace toilet=2 if v116!=11 

la def Ltoilet 1 "Flush to sewer" 2 "Flush to latrine/other" 
la val toilet Ltoilet

tabu toilet, gen(toilet_)

labnoeq toilet_?


****Smoking

gen cigarettes=v463a
gen nargile=v463f

la var cigarettes "Mother smokes cigarettes"
la var nargile "Mother smokes nargile" 


****Resident of HH

gen dejure=0
replace dejure=1 if v135==1 



/*Health knowledge
breastfeeding, foods, contraceptive knowledge, heard of oral rehydration, smoking
knowledge of TB and its spread
prenatal care, delivery care, duration of breastfeeding, postnatal care
m55 series (feeding), immunizations, had diarrhea recently, treatment of diarrhea

Community health characteristics from Census? 
Governorate level health services?
Peer effects--cluster averages from individuals from different households

v416
*/

*********************
*Feeding
*********************

*For youngest child born 2010+ 
gen match=s1102==b16 & hw1<24

*Drank from bottle with niiple
gen bottle=.
replace bottle=0 if m38==0
replace bottle=1 if m38==1

label variable bottle "Drank from bottle" 

foreach var of varlist v409 v410 v411 v411a v412a v412c v413 ///
v414e-v414p v414s v414t v414v {
gen c_`var'=0 if `var'==0
replace c_`var'=1 if `var'==1
}

*Sources of liquid
gen liquids=.
replace liquids=c_v409+c_v410+c_v411+c_v411a+ c_v412c+c_v413 if match==1

label variable liquids "No. liquids"

*Sources of grain and other foods
gen grains=.
replace grains=c_v412a+c_v414e+c_v414f+c_v414s if match==1

label variable grains "No. grains"

*Sources of protein
gen protein=.
replace protein=c_v414g+c_v414h+c_v414m+c_v414n+c_v414o+c_v414p+c_v414t+c_v414v if match==1

label variable protein "No. protein" 

*Sources of fruit and vegetables
gen fruitveg=.
replace fruitveg=c_v414i+c_v414j+c_v414k+c_v414l

label variable fruitveg "No. fruits and vegs."

*Total foods
gen foods=.
replace foods=c_v412a+c_v414e+c_v414f+c_v414g+c_v414h+c_v414i+c_v414j+c_v414k+c_v414l ///
+c_v414m+c_v414n+c_v414o+c_v414p+c_v414s+c_v414t+c_v414v+c_v414e if match==1


*Frequency of solid-soft food 
gen food_freq=.
replace food_freq=m39 if m39<5
replace food_freq=4 if m39==5 | m39==6 | m39==7

tabu food_freq, gen(foodfr_)

lab var foodfr_2 "Once" 
lab var foodfr_3 "Twice" 
lab var foodfr_4 "Three times"
lab var foodfr_5 "Four +"



*********************
*Breastfeeding
*********************

*Currently breastfed

gen currbf=.
replace currbf=0 if (m4==93 | m4==94) & match==1
replace currbf=1 if m4==95 & match==1

label variable currbf "Currently breastfed"

*Exclusively breastfed

gen exclbf=.

replace exclbf=0 if (v409==0 | v410==0 | v411==0 | v411a==0 | v412a==0 ///
| v412c==0 | v413==0 | v414e==0 | v414f==0 | v414g==0 | v414h==0 ///
| v414i==0 | v414j==0 | v414k==0 | v414l==0 | v414m==0 | v414n==0 ///
| v414o==0 | v414p==0 | v414s==0 | v414t==0 | v414v==0 | v404==1) & match==1


replace exclbf=1 if v409==0 & v410==0 & v411==0 & v411a==0 & v412a==0 ///
& v412c==0 & v413==0 & v414e==0 & v414f==0 & v414g==0 & v414h==0 ///
& v414i==0 & v414j==0 & v414k==0 & v414l==0 & v414m==0 & v414n==0 ///
& v414o==0 & v414p==0 & v414s==0 & v414t==0 & v414v==0 & v404==1 & match==1

label variable exclbf "Exclusively breastfed"


*Ever breastfed

gen everbf=.
replace everbf=1 if m4==93 | m4==95
replace everbf=0 if m4==94

label variable everbf "Ever breastfed"

*Breastfeeding for last birth
gen bftime=.
replace bftime=0 if v426==. & match==1
replace bftime=1 if v426==0  & match==1
replace bftime=2 if v426==100  & match==1
replace bftime=3 if v426==101  & match==1
replace bftime=4 if v426>=102 & v426<=124  & match==1
replace bftime=5 if v426==201  & match==1
replace bftime=6 if v426==202  & match==1
replace bftime=7 if v426>=203 & v426<=260  & match==1

label variable bftime "Breastfeeding initiation for last birth"

la def Lbftime 0 "Not breastfed" 1 "Immediately" 2 "Within first hour" ///
3 "One hour" 4 "2-24 hours" 5 "One day" 6 "Two days" 7 "3 or more days"

la val bftime Lbftime

clonevar ch_bftime=bftime
replace ch_bftime=0 if everbf==0 & match==1

tabu ch_bftime, gen(chbf_)

labnoeq chbf_?


*Given other liquids in first 3 days
gen other3=.
*Assume that those not breastfed received something else
replace other3=1 if everbf==0 & match==1
replace other3=1 if (m55a==1 | m55b==1 | m55c==1 | m55d==1 | m55e==1 | m55f==1 ///
| m55g==1 | m55h==1 | m55i==1 | m55x==1) & match==1
replace other3=0 if (m55a==0 & m55b==0 & m55c==0 & m55d==0 & m55e==0 & m55f==0 ///
& m55g==0 & m55h==0 & m55i==0 & m55x==0) & match==1

label variable other3 "Other liquids within 3 days birth"

**********************
*Health and Illness
**********************

*Diarrhea in the past two weeks and persistence (still have)
gen diar=.
replace diar=0 if h11==0
replace diar=1 if h11==2
replace diar=2 if s521b==1

label variable diar "Diarrhea and persistence"

la def Ldiar 0 "None" 1 "Yes but gone" 2 "Yes still"
la val diar Ldiar

tabu diar, gen (diar_)

labnoeq diar_?


*Fever/cough in past two weeks and persistence
gen fever=.
replace fever=0 if h31==0 & h22==0
replace fever=1 if h31==2 | h22==1
replace fever=2 if s536b==1 | s536b==2 | s536b==4

la var fever "Fever or cough and persistence" 
la val fever Ldiar

tabu fever, gen(fever_)

labnoeq fever_?


**********************
*Knowledge factors
**********************

gen know_ORS=0
replace know_ORS=1 if v416==1 | v416==2

label variable know_ORS "Know of ORS"

foreach var of varlist s916a_* {
gen c_`var'=0
replace c_`var'=1 if `var'==1
}

sum c_s916a_*

factor c_s916a_a-c_s916a_f c_s916a_h-c_s916a_z

factor c_s916a_a-c_s916a_f c_s916a_h-c_s916a_z , factors(1)

predict std_know

gen TB_curable=.
replace TB_curable=0 if v474==0 | v475==0 | v475==8
replace TB_curable=1 if v475==1

label variable TB_curable "Know TB is curable"

sum s714_*
factor s714_*
factor s714_*, factors(1)

predict FP_know 

label variable FP_know "Exposure to family planning" 


**********************
*Validity Measures
**********************

gen htvalid=1

foreach var of varlist hta_sd wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
 month_2-month_23  ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_4 liquids grains protein fruitveg ///
 diar_2-diar_3 fever_2-fever_3 water_2 water_3 toilet_2 ///
TB_curable know_ORS FP_know mage_2-mage_7 mtht dist_prob bweight {
replace htvalid=0 if `var'==.
}
replace htvalid=0 if match!=1 | dejure!=1


gen wtvalid=1

foreach var of varlist wta_sd wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
 month_2-month_23  ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_4 liquids grains protein fruitveg ///
 diar_2-diar_3 fever_2-fever_3 water_2 water_3 toilet_2 ///
TB_curable know_ORS FP_know mage_2-mage_7 mtht dist_prob bweight {
replace wtvalid=0 if `var'==.
}
replace wtvalid=0 if match!=1 | dejure!=1


gen whvalid=1

foreach var of varlist wth_sd wscore wscore2 faed2-faed6 moed2-moed6 ///
ftemp2-ftemp4 mtemp2-mtemp3 ftocp3-ftocp9 mtocp3-mtocp3 rural gov_2-gov_12 scamps badia ///
 month_2-month_23  ch_female ///
 chbf_2-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_2-foodfr_4 liquids grains protein fruitveg ///
 diar_2-diar_3 fever_2-fever_3 water_2 water_3 toilet_2 ///
TB_curable know_ORS FP_know mage_2-mage_7 mtht dist_prob bweight {
replace whvalid=0 if `var'==.
}
replace whvalid=0 if match!=1 | dejure!=1


****Dataset

save "FIJO data v1.dta", replace
