**Food and Inequality--Jordan 2012

*Graphs & Descriptives

**Version 6.0
**Caroline Krafft
**Original 11/25/14
**Updated 7/12/21
**STATA


use "FIJO data v1.dta", clear

***Graphs of nutrition

set scheme s1mono

preserve 

collapse hta_sd wta_sd wth_sd stunt underw waste [pw=hhweight], by(hw1 v190)

graph twoway lowess hta_sd hw1 if v190==1,  lcolor(gs0) bw(.4)  ///
|| lowess hta_sd hw1 if v190==2, lcolor(gs5) bw(.4) ///
|| lowess hta_sd hw1 if v190==3, lcolor(gs8) bw(.4) ///
|| lowess hta_sd hw1 if v190==4, lcolor(gs10)  bw(.4) ///
|| lowess hta_sd hw1 if v190==5,  lcolor(gs13) bw(.4) ///
||, ytitle("Height-for-Age, in SD") xtitle("Age in Months") ///
title("Height-for-Age") yline(0, lcolor(black) lpattern(dash)) ylabel(-1.5(.5)1.5) note("") ///
xlabel(0(10)60) xsize(20) ysize(20) legend(title("Wealth quintile", size(3)) ///
label(1 "Poorest") label(2 "Poorer") label(3 "Middle") ///
 label(4 "Richer") label(5 "Richest") size(3)) plotregion(margin(none))


graph save "HTA.gph", replace
graph export "HTA.tif", replace

graph twoway lowess wta_sd hw1 if v190==1,  lcolor(gs0) bw(.4)  ///
|| lowess wta_sd hw1 if v190==2, lcolor(gs5) bw(.4) ///
|| lowess wta_sd hw1 if v190==3, lcolor(gs8) bw(.4) ///
|| lowess wta_sd hw1 if v190==4, lcolor(gs10)  bw(.4) ///
|| lowess wta_sd hw1 if v190==5,  lcolor(gs13) bw(.4) ///
||, ytitle("Weight-for-Age, in SD") xtitle("Age in Months") ///
title("Weight-for-Age") yline(0, lcolor(black) lpattern(dash)) ylabel(-1.5(.5)1.5) note("") ///
xlabel(0(10)60) xsize(20) ysize(20) legend(title("Wealth quintile", size(3)) ///
label(1 "Poorest") label(2 "Poorer") label(3 "Middle") ///
 label(4 "Richer") label(5 "Richest") size(3)) plotregion(margin(none))


graph save "WTA.gph", replace
graph export "WTA.tif", replace

graph twoway lowess wth_sd hw1 if v190==1,  lcolor(gs0) bw(.4)  ///
|| lowess wth_sd hw1 if v190==2, lcolor(gs5) bw(.4) ///
|| lowess wth_sd hw1 if v190==3, lcolor(gs8) bw(.4) ///
|| lowess wth_sd hw1 if v190==4, lcolor(gs10)  bw(.4) ///
|| lowess wth_sd hw1 if v190==5,  lcolor(gs13) bw(.4) ///
||, ytitle("Weight-for-Height, in SD") xtitle("Age in Months") ///
title("Weight-for-Height") yline(0, lcolor(black) lpattern(dash)) ylabel(-1.5(.5)1.5) note("") ///
xlabel(0(10)60) xsize(20) ysize(20) legend(title("Wealth quintile", size(3)) ///
label(1 "Poorest") label(2 "Poorer") label(3 "Middle") ///
 label(4 "Richer") label(5 "Richest") size(3)) plotregion(margin(none))

gen stunt_100=stunt*100
gen underw_100=underw*100
gen waste_100=waste*100



graph save "WHT.gph", replace
graph export "WHT.tif", replace

graph twoway lowess stunt_100 hw1 if v190==1,  lcolor(gs0) bw(.4)  ///
|| lowess stunt_100 hw1 if v190==2, lcolor(gs5) bw(.4) ///
|| lowess stunt_100 hw1 if v190==3, lcolor(gs8) bw(.4) ///
|| lowess stunt_100 hw1 if v190==4, lcolor(gs10)  bw(.4) ///
|| lowess stunt_100 hw1 if v190==5,  lcolor(gs13) bw(.4) ///
||, ytitle("Percentage Stunted") xtitle("Age in Months") ///
title("Stunted")  ylabel(0(5)30) note("") ///
xlabel(0(10)60) xsize(20) ysize(20) legend(title("Wealth quintile", size(3)) ///
label(1 "Poorest") label(2 "Poorer") label(3 "Middle") ///
 label(4 "Richer") label(5 "Richest") size(3)) plotregion(margin(none))


graph save "stunt.gph", replace
graph export "stunt.tif", replace

graph twoway lowess underw_100 hw1 if v190==1,  lcolor(gs0) bw(.4)  ///
|| lowess underw_100 hw1 if v190==2, lcolor(gs5) bw(.4) ///
|| lowess underw_100 hw1 if v190==3, lcolor(gs8) bw(.4) ///
|| lowess underw_100 hw1 if v190==4, lcolor(gs10)  bw(.4) ///
|| lowess underw_100 hw1 if v190==5,  lcolor(gs13) bw(.4) ///
||, ytitle("Percentage Underweight") xtitle("Age in Months") ///
title("Underweight") ylabel(0(5)30) note("") ///
xlabel(0(10)60) xsize(20) ysize(20) legend(title("Wealth quintile", size(3)) ///
label(1 "Poorest") label(2 "Poorer") label(3 "Middle") ///
 label(4 "Richer") label(5 "Richest") size(3)) plotregion(margin(none))

graph save "underw.gph", replace
graph export "underw.tif", replace

graph twoway lowess waste_100 hw1 if v190==1,  lcolor(gs0) bw(.4)  ///
|| lowess waste_100 hw1 if v190==2, lcolor(gs5) bw(.4) ///
|| lowess waste_100 hw1 if v190==3, lcolor(gs8) bw(.4) ///
|| lowess waste_100 hw1 if v190==4, lcolor(gs10)  bw(.4) ///
|| lowess waste_100 hw1 if v190==5,  lcolor(gs13) bw(.4) ///
||, ytitle("Percentage Wasted") xtitle("Age in Months") ///
title("Wasted") ylabel(0(5)30) note("") ///
xlabel(0(10)60) xsize(20) ysize(20) legend(title("Wealth quintile", size(3)) ///
label(1 "Poorest") label(2 "Poorer") label(3 "Middle") ///
 label(4 "Richer") label(5 "Richest") size(3)) plotregion(margin(none))

graph save "waste.gph", replace
graph export "waste.tif", replace

**********
*Figure 2
**********

grc1leg "HTA.gph" "WTA.gph" "WHT.gph" "stunt.gph" "underw.gph" "waste.gph", ///
rows(3) cols(2) colfirst xsize(12) ysize(18)
graph display, xsize(12) ysize(20)

graph save "anthro_wiq.gph", replace
graph export "anthro_wiq.tif", replace width(1500)

restore



*Distributions 

set scheme s1mono

tw kdensity hta_sd [aw=hhweight], lwidth(thick)  ///
 xline(0, lwidth(thick) lpattern(dash)) ///
 xline(-2, lwidth(thick) lpattern(dash)) ///
 xline(2, lwidth(thick) lpattern(dash)) ///
 xlab(-2 "-2 SD (Stunted)" 0 "Median" 2 "2 SD") ///
ytitle(Proportion of Children) xtitle(Z-score height-for-age) legend(label ///
(1 "Children in Jordan") ) plotregion(margin(none))

graph save "HTAd.gph", replace
graph export "HTAd.tif", replace


tw kdensity wta_sd [aw=hhweight], lwidth(thick)  ///
 xline(0, lwidth(thick) lpattern(dash)) ///
 xline(-2, lwidth(thick) lpattern(dash)) ///
 xline(2, lwidth(thick) lpattern(dash)) ///
 xlab(-2 "-2 SD (Underweight)" 0 "Median" 2 "2 SD") ///
ytitle(Proportion of Children) xtitle(Z-score weight-for-age) legend(label ///
(1 "Children in Jordan") ) plotregion(margin(none))

graph save "WTAd.gph", replace
graph export "WTAd.tif", replace


tw kdensity wth_sd [aw=hhweight], lwidth(thick)  ///
 xline(0, lwidth(thick) lpattern(dash)) ///
 xline(-2, lwidth(thick) lpattern(dash)) ///
 xline(2, lwidth(thick) lpattern(dash)) ///
 xlab(-2 "-2 SD (Wasted)" 0 "Median" 2 "2 SD") ///
ytitle(Proportion of Children) xtitle(Z-score weight-for-height) legend(label ///
(1 "Children in Jordan") ) plotregion(margin(none))

graph save "WHTd.gph", replace
graph export "WHTd.tif", replace

*********
*Figure 1
*********


graph combine "HTAd.gph" "WTAd.gph" "WHTd.gph", ///
rows(3) cols(1) xsize(12) ysize(18)

graph save "distr.gph", replace
graph export "distr.tif", replace width(1500)





************************
*Descriptive Statistics
************************

use "FIJO data v1.dta", clear

gen stunt_100=stunt*100
gen underw_100=underw*100
gen waste_100=waste*100

tabout faed_cat moed_cat v190 ftempst mtempst ftocp1d mtocp1d if match==1 [aw=hhweight] ///
using SESanthro.csv, replace ///
c(mean hta mean wta mean wth mean stunt_100 mean underw_100 mean waste_100) npos(row) ///
layout(col) sum format(3 3 3 1 1 1) ptotal(single) lines(none)

****Means of explanatory variables

labnoeq month_1?
labnoeq month_2?

la var foodfr_1 "None"

gen urban=1-rural

la var urban "Urban"

gen nonbadia=1-badia

la var nonbadia "Not badia"

gen nonscamps=1-scamps

la var nonscamps "Not camps"

gen ch_male=1-ch_female

la var ch_male "Male"

tabstat wscore wscore2 faed1-faed6 moed1-moed6 ///
ftemp1-ftemp4 mtemp1-mtemp3 ftocp1-ftocp9 mtocp1-mtocp3 ///
rural scamps badia gov_1-gov_12  ///
 month_1-month_24 ch_female ///
chbf_1-chbf_8 other3 exclbf currbf  ///
 bottle foodfr_1-foodfr_5 liquids grains protein fruitveg ///
  diar_1-diar_3 fever_1-fever_3 roomspp c_wealth c_wealth2 c_nosewer ///
  c_water_1 c_water_2 c_water_3 c_water_4 water_1 water_2 water_3 water_4 ///
  toilet_2 hh_smoke cigarettes nargile dist_prob ///
TB_curable know_ORS FP_know mage_1-mage_7 mtht bspace firstb ///
bweight bweightm if dejure==1 & match==1 &whvalid==1  [aw=hhweight], save stats(mean sd)


matrix define expl=r(StatTotal)'

estadd matrix expl, replace

estout matrix(expl,f(%9.3f)) using "FIJOdescX.xls", replace ///
label ///
refcat(wscore "Wealth" faed1 "Father's education" ///
moed1 "Mother's education" ftemp1 "Father's emp. status" ///
mtemp1 "Mother's employment status" ///
ftocp1 "Father's occup." mtocp1 "Mother's occup." ///
gov_1 "Gov. of residence" month_1 "Age in months" ///
chbf_1 "Breastfeeding init." ///
foodfr_1 "Feeding frequency"  diar_1 "Diarrhea" ///
fever_1 "Fever/Cough"  ///
c_water_1 "Cluster water" ///
water_1 "Household Water" ///
 mage_1 "Mother's age")

